# screening-ai
API Documentation for Screening AI

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.0
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/Resumepal/screening_ai_python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/Resumepal/screening_ai_python.git`)

Then import the package:
```python
import screening_ai
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import screening_ai
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import screening_ai
from screening_ai.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.

# You can replace host with your own server URL if you are not using ByteRaven managed API server.
configuration = screening_ai.Configuration(
    host = "http://localhost" 
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: X-API-KEY
configuration.api_key['X-API-KEY'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'


# Enter a context with an instance of the API client
with screening_ai.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = screening_ai.PlatformScreeningJobsApi(api_client)
    platform_create_screening_job_dto = screening_ai.PlatformCreateScreeningJobDto() # PlatformCreateScreeningJobDto | 

    try:
        # Create a new Screening Job
        api_response = api_instance.platform_screening_jobs_controller_create_screening_job(platform_create_screening_job_dto)
        print("The response of PlatformScreeningJobsApi->platform_screening_jobs_controller_create_screening_job:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling PlatformScreeningJobsApi->platform_screening_jobs_controller_create_screening_job: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PlatformScreeningJobsApi* | [**platform_screening_jobs_controller_create_screening_job**](docs/PlatformScreeningJobsApi.md#platform_screening_jobs_controller_create_screening_job) | **POST** /api/v2/platform/platform-screening-job | Create a new Screening Job
*PlatformScreeningJobsApi* | [**platform_screening_jobs_controller_get_screening_job_using_id**](docs/PlatformScreeningJobsApi.md#platform_screening_jobs_controller_get_screening_job_using_id) | **GET** /api/v2/platform/platform-screening-job/id | Get Screening Job using Id
*PlatformScreeningJobsApi* | [**platform_screening_jobs_controller_get_screening_jobs_of_org**](docs/PlatformScreeningJobsApi.md#platform_screening_jobs_controller_get_screening_jobs_of_org) | **GET** /api/v2/platform/platform-screening-job/org | Get all Screening Jobs of Organisation
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_convert_audio_to_text**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_convert_audio_to_text) | **POST** /api/v2/platform/platform-screening-submission/textFromAudio | Convert Audio to Text
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_create_screening_stream_room**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_create_screening_stream_room) | **POST** /api/v2/platform/platform-screening-submission/stream/start | Create Screening Submission Streaming Room
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_create_screening_submission**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_create_screening_submission) | **POST** /api/v2/platform/platform-screening-submission | Create a new Screening Submission
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_get_screening_submission_using_id**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_get_screening_submission_using_id) | **GET** /api/v2/platform/platform-screening-submission/id | Get Screening Submission using ID
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_get_screening_submissions_of_org**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_get_screening_submissions_of_org) | **POST** /api/v2/platform/platform-screening-submission/org/filters | Get Screening Submissions of an Organisation
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_get_screening_submissions_using_email_phone**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_get_screening_submissions_using_email_phone) | **GET** /api/v2/platform/platform-screening-submission/email-phone | Get Screening Submission using Email ir Phone
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_get_screening_submissions_using_job_id**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_get_screening_submissions_using_job_id) | **GET** /api/v2/platform/platform-screening-submission/jobId | Get Screening Submissions using Job ID
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_update_screening_submission_chat**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_update_screening_submission_chat) | **PUT** /api/v2/platform/platform-screening-submission | Update Screening Submission Chat Objects
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_update_screening_submission_status**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_update_screening_submission_status) | **PUT** /api/v2/platform/platform-screening-submission/status | Update Screening Submission Status
*PlatformScreeningSubmissionsApi* | [**platform_screening_submissions_controller_update_screening_submission_view_status**](docs/PlatformScreeningSubmissionsApi.md#platform_screening_submissions_controller_update_screening_submission_view_status) | **PUT** /api/v2/platform/platform-screening-submission/view | Update Screening Submission View Status
*PlatformScreeningTemplatesApi* | [**platform_screening_templates_controller_create_screening_template**](docs/PlatformScreeningTemplatesApi.md#platform_screening_templates_controller_create_screening_template) | **POST** /api/v2/platform/platform-screening-template | Create a new Screening Template
*PlatformScreeningTemplatesApi* | [**platform_screening_templates_controller_generate_screening_template_questions**](docs/PlatformScreeningTemplatesApi.md#platform_screening_templates_controller_generate_screening_template_questions) | **POST** /api/v2/platform/platform-screening-template/generateQuestions | Generate Screening Template Questions
*PlatformScreeningTemplatesApi* | [**platform_screening_templates_controller_get_screening_templates**](docs/PlatformScreeningTemplatesApi.md#platform_screening_templates_controller_get_screening_templates) | **GET** /api/v2/platform/platform-screening-template | Get all Screening Templates of Organisation


## Documentation For Models

 - [ApiResponseWrapper](docs/ApiResponseWrapper.md)
 - [ApiResponseWrapperData](docs/ApiResponseWrapperData.md)
 - [CreatePlatformOrganisationBillingStripeSessionResponseDto](docs/CreatePlatformOrganisationBillingStripeSessionResponseDto.md)
 - [CreatePlatformScreeningFormSubmissionDto](docs/CreatePlatformScreeningFormSubmissionDto.md)
 - [CreatePlatformScreeningSubmissionResponseDto](docs/CreatePlatformScreeningSubmissionResponseDto.md)
 - [CreatePlatformScreeningSubmissionStreamingRoomTokenDto](docs/CreatePlatformScreeningSubmissionStreamingRoomTokenDto.md)
 - [CreateScreeningTemplateDto](docs/CreateScreeningTemplateDto.md)
 - [GenerateScreeningTemplateQuestionsDto](docs/GenerateScreeningTemplateQuestionsDto.md)
 - [GetAllOrganisationMemberStatusOfOrgListResponseDto](docs/GetAllOrganisationMemberStatusOfOrgListResponseDto.md)
 - [GetAllPlatformScreeningTemplatesOfOrgResponseDto](docs/GetAllPlatformScreeningTemplatesOfOrgResponseDto.md)
 - [GetOrganisationBillingViaOrgIdResponseDto](docs/GetOrganisationBillingViaOrgIdResponseDto.md)
 - [GetOrganisationMemberStatusResponseDto](docs/GetOrganisationMemberStatusResponseDto.md)
 - [GetPlatformOrganisationApiKeyResponseDto](docs/GetPlatformOrganisationApiKeyResponseDto.md)
 - [GetPlatformScreeningSubmissionsOfOrgDto](docs/GetPlatformScreeningSubmissionsOfOrgDto.md)
 - [PlatformCreateScreeningJobDto](docs/PlatformCreateScreeningJobDto.md)
 - [PlatformOrganisationResponseDto](docs/PlatformOrganisationResponseDto.md)
 - [PlatformOrganisationsListResponseDto](docs/PlatformOrganisationsListResponseDto.md)
 - [PlatformScreeningJobListResponseDto](docs/PlatformScreeningJobListResponseDto.md)
 - [PlatformScreeningJobResponseDto](docs/PlatformScreeningJobResponseDto.md)
 - [PlatformScreeningSubmissionCreateStreamRoomResponseDto](docs/PlatformScreeningSubmissionCreateStreamRoomResponseDto.md)
 - [PlatformScreeningSubmissionListResponseDto](docs/PlatformScreeningSubmissionListResponseDto.md)
 - [PlatformScreeningSubmissionResponseDto](docs/PlatformScreeningSubmissionResponseDto.md)
 - [PlatformScreeningSubmissionTextFromAudioResponseDto](docs/PlatformScreeningSubmissionTextFromAudioResponseDto.md)
 - [PlatformUserJwtResponseDto](docs/PlatformUserJwtResponseDto.md)
 - [PlatformUserResponseDto](docs/PlatformUserResponseDto.md)
 - [ScreeningFormSubmissionQuestionDto](docs/ScreeningFormSubmissionQuestionDto.md)
 - [UpdatePlatformScreeningSubmissionChatDto](docs/UpdatePlatformScreeningSubmissionChatDto.md)
 - [UpdatePlatformScreeningSubmissionsStatusDto](docs/UpdatePlatformScreeningSubmissionsStatusDto.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="X-API-KEY"></a>
### X-API-KEY

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

<a id="JWT"></a>
### JWT

- **Type**: Bearer authentication (JWT)


## Author




